@@ -13,13 +13,13 @@ test_that("modelling works", {
   expect_equal(length(which(model@data$Presence == 0)), 1000)
   model = data.values(model, Env)
   expect_equal(dim(model@data), c(1057, 6))
-  model = evaluate(model, cv = "holdout", cv.param = c(0.7, 2), thresh = 1001,
-                   metric = "SES", Env)
-  expect_equal(dim(model@evaluation), c(1, 7))
+  model = evaluate(model, cv = "holdout", cv.param = c(0.7, 2), final.fit.data = 'all', bin.thresh="SES", thresh = 1001, metric = NULL, Env)
+  expect_equal(dim(model@evaluation), c(1, 8))
+  expect_equal(dim(model@data), c(1057, 7))
+  expect_true(is.logical(model@data$train))
   model = project(model, Env)
   expect_equal(all(is.na(values(model@projection))), FALSE)
-  model = evaluate.axes(model, cv.param = c(0.7, 2), thresh = 1001, metric = "SES",
-                        axes.metric = "Pearson", Env)
+  model = evaluate.axes(model, cv.param = c(0.7, 2), final.fit.data = 'all', bin.thresh="SES", metric = NULL, thresh = 1001, axes.metric = "Pearson", Env)
   expect_equal(dim(model@variable.importance), c(1, 3))
   # expect_equal(NULL, print(model))
 })
